Day18

Struct Day18 

pub struct Day18 { /* private fields */ }
2019 Day 18: Finding the shortest path to collect every key.

The key optimization is to precompute the distance between all entrances and keys, along with the keys required to travel each path. This allows the final search to only track each robot’s position and which keys remain.

Implementations

Source

impl Day18

pub fn new(input: &str, _: InputType) -> Result<Self, InputError>

pub fn part1(&self) -> u32

pub fn part2(&self) -> u32