pub struct Day25 { /* private fields */ }Expand description
2019 Day 25: Interpreting machine code to complete a text adventure game.
This solution makes many assumptions derived from running the puzzle input.
Implementations