pub struct Day18 { /* private fields */ }Expand description
2019 Day 18: Finding the shortest path to collect every key.
The key optimization is to precompute the distance between all entrances and keys, along with the keys required to travel each path. This allows the final search to only track each robot’s position and which keys remain.
Implementations